@@ -1,10 +1,12 @@
 from __future__ import annotations
 
 import copy
+import math
 import os
 import re
 import sys
 import tempfile
+from collections import Counter
 from curses import ascii
 from io import BytesIO
 from pathlib import Path
@@ -13,6 +15,7 @@ from typing.io import IO
 import fsutil
 import ots
 from fontTools import unicodedata
+from fontTools.pens.svgPathPen import SVGPathPen
 from fontTools.subset import Options as SubsetterOptions
 from fontTools.subset import Subsetter
 from fontTools.ttLib import TTCollection, TTFont, TTLibError
@@ -1032,6 +1035,61 @@ class Font:
             or ""
         )
 
+    def get_svg(
+        self,
+        *,
+        text: str,
+        size: int,
+    ) -> str:
+        """
+        Gets an SVG representation of the font rendering
+        some text using the given options.
+
+        :param text: The text to be rendered as SVG paths.
+        :type text: str
+        :param size: The size of the font to be used for rendering the text, in points.
+        :type size: int
+
+        :returns: An SVG string that represents the rendered text.
+        :rtype: str
+        """
+        font = self.get_ttfont()
+
+        # get font metrics
+        units_per_em = font["head"].unitsPerEm
+        scale = size / units_per_em
+        hhea = font["hhea"]
+        ascent = hhea.ascent * scale
+        descent = hhea.descent * scale
+        width = 0
+        height = ascent - descent
+
+        # get glyph set and character map
+        glyphset = font.getGlyphSet()
+        cmap = font["cmap"].getBestCmap()
+
+        # generate svg path for each glyph in text
+        glyphs: list[str] = list(filter(None, [cmap.get(ord(char)) for char in text]))
+        paths = ""
+        for glyph_name in glyphs:
+            glyph = glyphset[glyph_name]
+            pen = SVGPathPen(glyphset)
+            glyph.draw(pen)
+            commands = pen.getCommands()
+            transform = f"translate({width:.2f} {ascent:.2f}) scale({scale} -{scale})"
+            paths += f"""<path d="{commands}" transform="{transform}" />"""
+            width += glyph.width * scale
+
+        # round width and height
+        width = int(math.ceil(width))
+        height = int(math.ceil(height))
+        viewbox = f"0 0 {width} {height}"
+        xmlns = "http://www.w3.org/2000/svg"
+
+        # generate svg string
+        svg_str = f"""<svg width="{width}" height="{height}" viewBox="{viewbox}" xmlns="{xmlns}">{paths}</svg>"""
+        return svg_str
+
     def get_ttfont(
         self,
     ) -> TTFont:
@@ -1394,18 +1452,41 @@ class Font:
         width["value"] = width_value
         return width
 
-    def is_monospace(
+    def is_color(
         self,
+    ) -> bool:
+        """
+        Determines if the font is a color font.
+
+        :returns: True if color font, False otherwise.
+        :rtype: bool
+        """
+        font = self.get_ttfont()
+        tables = {"COLR", "CPAL", "CBDT", "CBLC"}
+        for table in tables:
+            if table in font:
+                return True
+        return False
+
+    def is_monospace(
+        self,
+        threshold: float = 0.85,
     ) -> bool:
         """
         Determines if the font is a monospace font.
 
+        :param threshold: The threshold (0.0 <= n <= 1.0) of glyphs with the same width to consider the font as monospace.
+        :type threshold: float
+
         :returns: True if monospace font, False otherwise.
         :rtype: bool
         """
         font = self.get_ttfont()
-        widths = {metrics[0] for metrics in font["hmtx"].metrics.values()}
-        return len(widths) == 1
+        widths = [metrics[0] for metrics in font["hmtx"].metrics.values()]
+        widths_counter = Counter(widths)
+        same_width_count = widths_counter.most_common(1)[0][1]
+        same_width_amount = same_width_count / self.get_glyphs_count()
+        return same_width_amount >= threshold
 
     def is_static(
         self,
